import 'dart:io';
import 'option.dart';

class Terminal {
  const Terminal();

  /// printPrompt
  ///
  /// Print a prompt.
  void printPrompt(String prompt, bool withCaret) {
    if (!stdout.hasTerminal) return;

    if (!withCaret) {
      stdout.writeln(prompt);
    } else {
      stdout.write('$prompt>');
    }
  }

  /// collectInput
  ///
  /// Read the content of a line synchronously.
  String collectInput() {
    if (!stdout.hasTerminal) return null;
    return stdin.readLineSync();
  }

  /// printOptions
  ///
  /// Display the list of options.
  void printOptions(List<Option> options) {
    options.asMap().forEach((idx, opt) {
      stdout.writeln('$idx - ${opt.label}');
    });
    stdout.write('Enter a choice>');
  }

  /// clearScreen
  ///
  /// Clear the screen according to the operating system.
  void clearScreen() {
    if (!stdout.hasTerminal) return;

    switch (Platform.operatingSystem.toString()) {
      case 'windows':
        stdout.write('\x1B[2J\x1B[0f');
        break;
      case 'linux':
        stdout.write('\x1B[2J\x1B[3J\x1B[H');
        break;
      case 'macos':
        stdout.write('\x1B[2J\x1B[3J\x1B[H');
        break;
      case 'android':
        stdout.write('\x1B[2J\x1B[3J\x1B[H');
        break;
      case 'ios':
        stdout.write('\x1B[2J\x1B[3J\x1B[H');
        break;
      default:
        stdout.writeln('Platform Unknown!');
    }
  }
}
